[sr-dev] git:master: rls: fixed supported header name

Elena-Ramona Modroiu ramona at rosdev.ro
Tue Aug 25 10:38:45 CEST 2009


Module: sip-router
Branch: master
Commit: a3b0f700d10d0b310766a34ec6e7390455e5ba64
URL:    http://git.sip-router.org/cgi-bin/gitweb.cgi/sip-router/?a=commit;h=a3b0f700d10d0b310766a34ec6e7390455e5ba64

Author: Elena-Ramona Modroiu <ramona at rosdev.ro>
Committer: Elena-Ramona Modroiu <ramona at rosdev.ro>
Date:   Tue Aug 25 11:16:53 2009 +0300

rls: fixed supported header name

- port of K #5908

---

 modules_k/rls/subscribe.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/modules_k/rls/subscribe.c b/modules_k/rls/subscribe.c
index eada0c6..7f1c365 100644
--- a/modules_k/rls/subscribe.c
+++ b/modules_k/rls/subscribe.c
@@ -476,7 +476,7 @@ int rls_handle_subscribe(struct sip_msg* msg, char* s1, char* s2)
 		lock_release(&rls_table[hash_code].lock);
 	}
 
 /*** verify if it contains the 'Support: eventlist' header
  * and if not - reply with '421 (Extension Required)' */
 
 /*
@@ -490,7 +490,7 @@ int rls_handle_subscribe(struct sip_msg* msg, char* s1, char* s2)
 	hdr= msg->headers;
 	while(hdr)
 	{
-		if(cmp_hdrname_strzn(&hdr->name, "Support", 7)== 0)
+		if(cmp_hdrname_strzn(&hdr->name, "Supported", 9)== 0)
 			break;
 		hdr= hdr->next;
 	}
@@ -476,7 +476,7 @@ int rls_handle_subscribe(struct sip_msg* msg, char* s1, char* s2)
 	}
 
-/*** verify if it contains the 'Support: eventlist' header
+/*** verify if it contains the 'Supported: eventlist' header
  * and if not - reply with '421 (Extension Required)' */
 




More information about the sr-dev mailing list